{
  "type": "record",
  "Aspect": {
    "name": "dataHubRemoteExecutorPoolGlobalConfig"
  },
  "name": "RemoteExecutorPoolGlobalConfig",
  "namespace": "com.linkedin.pegasus2avro.executorglobalconfig",
  "fields": [
    {
      "type": "string",
      "name": "defaultExecutorPoolId",
      "doc": "The default pool to use for tasks that require remote executors.\nReferences 'id' in com.linkedin.pegasus2avro.metadata.key.RemoteExecutorPoolKey"
    }
  ],
  "doc": "Global singleton storing configs for remote executor pools."
}